# Genetic search 

This is a tool for optimising sklearn-compatible models' hyperparameters.
It uses genetic algorithm so, it is much faster than GridSearchCV and gives
more consistent results than RandomizedSearchCV.

The class GeneticSearchCV is extended of the sklearn's class BaseSearchCV, so
it has the same functionality as sklearn's searches.

You are free to use, modify and copy the code.